#define LED_PIN     D2
#define BUTTON_PIN  D1

bool ledState = false;
bool lastButtonState = HIGH;

void setup() {
  Serial.begin(115200);
  pinMode(LED_PIN, OUTPUT);
  pinMode(BUTTON_PIN, INPUT_PULLUP);
  digitalWrite(LED_PIN, ledState);

  Serial.println("ESP32 ready. Use WebSerial or press the button to toggle LED.");
}

void loop() {
  // --- Handle WebSerial input ---
  if (Serial.available()) {
    String cmd = Serial.readStringUntil('\n');
    cmd.trim();

    if (cmd == "on") {
      ledState = true;
      Serial.println("LED turned ON (via WebSerial)");
    } else if (cmd == "off") {
      ledState = false;
      Serial.println("LED turned OFF (via WebSerial)");
    } else if (cmd == "toggle") {
      ledState = !ledState;
      Serial.print("LED toggled to ");
      Serial.println(ledState ? "ON" : "OFF");
    } else {
      Serial.println("Unknown command");
    }
    digitalWrite(LED_PIN, ledState);
  }

  // --- Handle button press ---
  bool buttonState = digitalRead(BUTTON_PIN);

  if (lastButtonState == HIGH && buttonState == LOW) {
    // Button just got pressed
    ledState = !ledState;
    digitalWrite(LED_PIN, ledState);
    Serial.print("LED toggled to ");
    Serial.println(ledState ? "ON (via button)" : "OFF (via button)");
    delay(200); // Debounce
  }

  lastButtonState = buttonState;
}
